/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.gameserver.dao.BossSpawnDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.services.custom.SpawnBoss;

/**
 * @author zxl001
 */
public class MySQL5BossSpawnDAO extends BossSpawnDAO {
	
	private static final Logger log = LoggerFactory.getLogger(MySQL5BossSpawnDAO.class);
	
	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public List<SpawnBoss> loadSpawnBoss() {
		final List<SpawnBoss> bosses = new ArrayList<SpawnBoss>();
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement("SELECT * FROM `boss_spawn`");
			ResultSet rset = stmt.executeQuery();
			while(rset.next()) {
				int bossid = rset.getInt("boss_id");
				int box_id = rset.getInt("box_id");
				int raceid = rset.getInt("race");
				int worldid = rset.getInt("world_id");
				float x = rset.getFloat("x");
				float y = rset.getFloat("y");
				float z = rset.getFloat("z");
				byte h = rset.getByte("h");
				String reward = rset.getString("rank_reward");
				int sptime = rset.getInt("spawn_time");
				long retime = rset.getLong("retime");
				String zoneNameString = rset.getString("zone_name");
				SpawnBoss boss = new SpawnBoss(bossid, box_id, raceid, worldid, x, y, z, h, reward, sptime, retime, zoneNameString);
				bosses.add(boss);
			}
		}
		catch (Exception e) {
			log.error("", e);
		}
		finally {
			DatabaseFactory.close(con);
		}
		return bosses;
	}

	@Override
	public void updataSpawn(SpawnBoss boss) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement("UPDATE boss_spawn SET retime=? WHERE boss_id=? AND x=? AND y=?");
			stmt.setLong(1, boss.getReSpawnTime());
			stmt.setInt(2, boss.getBossId());
			stmt.setFloat(3, boss.getX());
			stmt.setFloat(4, boss.getY());
			stmt.execute();
			stmt.close();
		}
		catch(Exception e) {
			log.error("", e);
		}
		finally {
			DatabaseFactory.close(con);
		}
	}
}
