/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.aionemu.commons.database.DB;
import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.commons.database.IUStH;
import com.aionemu.gameserver.dao.EquipmentSettingDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.gameobjects.player.EquipmentSetting;
import com.aionemu.gameserver.model.gameobjects.player.Player;

/**
 * @author 81002
 *
 */
public class MySQL5EquipmentSettingDAO extends EquipmentSettingDAO {

	private static final Logger log = LoggerFactory.getLogger(MySQL5EquipmentSettingDAO.class);
	
	private static final String SELECT_QUERY = "SELECT * FROM equipment_settings WHERE player_id=?";
	
	private static final String DELETE_QUERY = "DELETE FROM equipment_settings WHERE player_id=?";
	
	public static final String INSERT_QUERY = "INSERT INTO equipment_settings (player_id, equipment_id, display, rigth_weapon, left_weapon, helmet, jacket, glove, shoes, left_ear, rigth_ear, left_ring, rigth_ring, necklace, shoulder, leggings, rigth_battery, left_battery, wing, belt, rigth_sub_weapon, left_sub_weapon, feather, unk1, bracelet, unk2) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
	
	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public void loadEquipmentSetting(Player player) {
		Connection con = null;
		PreparedStatement stmt = null;
		try {
			con = DatabaseFactory.getConnection();
			stmt = con.prepareStatement(SELECT_QUERY);
			stmt.setInt(1, player.getObjectId());
			ResultSet rset = stmt.executeQuery();
			while(rset.next()) {
				int index = rset.getInt("equipment_id");
				EquipmentSetting setting = new EquipmentSetting(index);
				setting.setDisplay(rset.getInt("display"));
				setting.setRigthWeapon(rset.getInt("rigth_weapon"));
				setting.setLeftWeapon(rset.getInt("left_weapon"));
				setting.setHelmet(rset.getInt("helmet"));
				setting.setJacket(rset.getInt("jacket"));
				setting.setGlove(rset.getInt("glove"));
				setting.setShoes(rset.getInt("shoes"));
				setting.setLeftEarings(rset.getInt("left_ear"));
				setting.setRigthEarings(rset.getInt("rigth_ear"));
				setting.setLeftRing(rset.getInt("left_ring"));
				setting.setRigthRing(rset.getInt("rigth_ring"));
				setting.setNecklace(rset.getInt("necklace"));
				setting.setShoulder(rset.getInt("shoulder"));
				setting.setLeggings(rset.getInt("leggings"));
				setting.setRigthBattery(rset.getInt("rigth_battery"));
				setting.setLeftBattery(rset.getInt("left_battery"));
				setting.setWing(rset.getInt("wing"));
				setting.setBelt(rset.getInt("belt"));
				setting.setRigthSubWeapon(rset.getInt("rigth_sub_weapon"));
				setting.setLeftSubWeapon(rset.getInt("left_sub_weapon"));
				setting.setFearther(rset.getInt("feather"));
				setting.setUnk1(rset.getInt("unk1"));
				setting.setBracelet(rset.getInt("bracelet"));
				setting.setUnk2(rset.getInt("unk2"));
				player.getSettingList().put(setting);
			}
		}
		catch(Exception ex) {
			log.error("" + ex);
		}
		finally {
			DatabaseFactory.close(stmt, con);
		}
	}

	@Override
	public void store(Player player) {
		deleteSwitch(player.getObjectId());
		for(EquipmentSetting setting : player.getSettingList().getSettings()) {
			store(player.getObjectId(), setting);
		}
	}
	
	private boolean store(final int object_id, final EquipmentSetting setting) {
		return DB.insertUpdate(INSERT_QUERY, new IUStH(){

			@Override
			public void handleInsertUpdate(PreparedStatement stmt) throws SQLException {
				stmt.setInt(1, object_id);
				stmt.setInt(2, setting.getIndex());
				stmt.setInt(3, setting.getDisplay());
				stmt.setInt(4, setting.getRigthWeapon());
				stmt.setInt(5, setting.getLeftWeapon());
				stmt.setInt(6, setting.getHelmet());
				stmt.setInt(7, setting.getJacket());
				stmt.setInt(8, setting.getGlove());
				stmt.setInt(9, setting.getShoes());
				stmt.setInt(10, setting.getLeftEarings());
				stmt.setInt(11, setting.getRigthEarings());
				stmt.setInt(12, setting.getLeftRing());
				stmt.setInt(13, setting.getRigthRing());
				stmt.setInt(14, setting.getNecklace());
				stmt.setInt(15, setting.getShoulder());
				stmt.setInt(16, setting.getLeggings());
				stmt.setInt(17, setting.getRigthBattery());
				stmt.setInt(18, setting.getLeftBattery());
				stmt.setInt(19, setting.getWing());
				stmt.setInt(20, setting.getBelt());
				stmt.setInt(21, setting.getRigthSubWeapon());
				stmt.setInt(22, setting.getLeftSubWeapon());
				stmt.setInt(23, setting.getFearther());
				stmt.setInt(24, setting.getUnk1());
				stmt.setInt(25, setting.getBracelet());
				stmt.setInt(26, setting.getUnk2());
				stmt.execute();
			}
		});
	}
	
	private boolean deleteSwitch(final int object_id) {
		return DB.insertUpdate(DELETE_QUERY, new IUStH() {

			@Override
			public void handleInsertUpdate(PreparedStatement stmt) throws SQLException {
				stmt.setInt(1, object_id);
				stmt.execute();
			}
		});
	}
}
