/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.aionemu.commons.database.DB;
import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.commons.database.IUStH;
import com.aionemu.gameserver.dao.LegionApplyDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.gameobjects.PersistentState;
import com.aionemu.gameserver.model.team.legion.LegionApply;

/**
 * @author zxl001
 */
public class MySQL5LegionApplyDAO extends LegionApplyDAO {
	private static final Logger log = LoggerFactory.getLogger(MySQL5LegionApplyDAO.class);
	public static final String SELECT_QUERY = "SELECT * FROM `legion_apply` WHERE `legion_id`=?";
	public static final String INSERT_QUERY = "INSERT INTO `legion_apply` (`objectId`, `player_name`, `player_class`, `player_level`, `legion_id`, `introduction`, `apply_time`) VALUES (?,?,?,?,?,?,?)";
	public static final String UPDATA_QUERY = "UPDATE legion_apply SET `player_name` = ?, `player_class` = ?, `player_level` = ? WHERE `objectId` = ?";
	
	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}
	
	@Override
	public Map<Integer, LegionApply> loadLegionApplys(int legionId) {
		Connection con = null;
		final Map<Integer, LegionApply> applys = new HashMap<Integer, LegionApply>();
		try{
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement(SELECT_QUERY);
			stmt.setInt(1, legionId);
			ResultSet rset = stmt.executeQuery();
			while (rset.next()) {
				int objectId = rset.getInt("objectId");
				String playerName = rset.getString("player_name");
				int playerClass = rset.getInt("player_class");
				int level = rset.getInt("player_level");
				String introduction = rset.getString("introduction");
				int time = rset.getInt("apply_time");
				LegionApply apply = new LegionApply(objectId, playerName, playerClass, level, legionId, introduction, time);
				applys.put(objectId, apply);
			}
			rset.close();
			stmt.close();
		}
		catch(Exception ex) {
			
		}
		finally{
			DatabaseFactory.close(con);
		}
		return applys;
	}

	@Override
	public void store(LegionApply apply) {
		boolean result = false;
		switch(apply.getPersistentState()){
			case NEW:
				result = insertApply(apply);
				break;
			case DELETED:
				result = deleteApply(apply);
				break;
			case UPDATE_REQUIRED:
				result = updateApply(apply);
				break;
		}
		if (result)
			apply.setPersistentState(PersistentState.UPDATED);
	}

	/**
	 * @param apply
	 * @return
	 */
	private boolean updateApply(LegionApply apply) {
		Connection conn = null;
		try{
			conn = DatabaseFactory.getConnection();
			PreparedStatement stmt = conn.prepareStatement(UPDATA_QUERY);
			stmt.setString(1, apply.getPlayerName());
			stmt.setInt(2, apply.getPlayerClassId());
			stmt.setInt(3, apply.getPlayerLevel());
			stmt.setInt(4, apply.getPlayerObjectId());
			stmt.executeUpdate();
			stmt.close();
			return true;
		}catch(Exception ex){
			log.error(ex.toString());
			return false;
		}
		finally{
			DatabaseFactory.close(conn);
		}
	}

	/**
	 * @param apply
	 * @return
	 */
	private boolean deleteApply(final LegionApply apply) {
		return DB.insertUpdate("DELETE FROM legion_apply WHERE objectId = ?", new IUStH() {
			@Override
			public void handleInsertUpdate(PreparedStatement stmt) throws SQLException {
				stmt.setInt(1, apply.getPlayerObjectId());
				stmt.execute();
			}
		});
	}

	/**
	 * @param apply
	 * @return
	 */
	private boolean insertApply(LegionApply apply) {
		Connection conn = null;
		try{
			conn = DatabaseFactory.getConnection();
			PreparedStatement stmt = conn.prepareStatement(INSERT_QUERY);
			stmt.setInt(1, apply.getPlayerObjectId());
			stmt.setString(2, apply.getPlayerName());
			stmt.setInt(3, apply.getPlayerClassId());
			stmt.setInt(4, apply.getPlayerLevel());
			stmt.setInt(5, apply.getApplyLegionId());
			stmt.setString(6, apply.getApplyIntroduction());
			stmt.setInt(7, apply.getApplyTime());
			stmt.executeUpdate();
			stmt.close();
			return true;
		}catch(Exception ex){
			log.error(ex.toString());
			return false;
		}
		finally{
			DatabaseFactory.close(conn);
		}
	}
}
