/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javolution.util.FastMap;

import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.gameserver.dao.MotionTimeDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.Gender;
import com.aionemu.gameserver.model.PlayerClass;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.motiontime.ClassTime;
import com.aionemu.gameserver.model.motiontime.Job;
import com.aionemu.gameserver.model.motiontime.MotionTime;
import com.aionemu.gameserver.model.motiontime.Times;
import com.aionemu.gameserver.model.motiontime.WeaponTypeWrapper;
import com.aionemu.gameserver.model.templates.item.WeaponType;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author zxl001
 */
public class MySQL5MotionTimeDAO extends MotionTimeDAO {

	private static Logger log = LoggerFactory.getLogger(MySQL5MotionTimeDAO.class);
	public static final String SELECT_QUERY = "SELECT * FROM skill_motions";
	public static final String INSERT_QUERY = "INSERT INTO skill_motions (motion_name, race, gender, player_class, weapon_type, off_weapon_type, time) VALUES (?,?,?,?,?,?,?)";
	public static final String UPDATE_QUERY = "UPDATE `skill_motions` SET `time` = ? WHERE `motion_name` = ? AND `race` = ? AND `gender` = ? AND `player_class` = ? AND `weapon_type` = ? AND `off_weapon_type` = ?";
	@Override
	public FastMap<String, MotionTime> loadMotionTime() {
		FastMap<String, MotionTime> motiontimes = new FastMap<String, MotionTime>();
		Connection con = null;
		PreparedStatement stmt = null;
		try {
			con = DatabaseFactory.getConnection();
			stmt = con.prepareStatement(SELECT_QUERY);
			ResultSet resultSet = stmt.executeQuery();
			while (resultSet.next()) {
				String name = resultSet.getString("motion_name");
				Race race = Race.valueOf(resultSet.getString("race"));
				Gender gender = Gender.valueOf(resultSet.getString("gender"));
				PlayerClass playerClass = PlayerClass.valueOf(resultSet.getString("player_class"));
				WeaponType weaponType = resultSet.getString("weapon_type").equals("NONE") ? null : WeaponType.valueOf(resultSet.getString("weapon_type"));
				WeaponType offweaponType = resultSet.getString("off_weapon_type").equals("NONE") ? null : WeaponType.valueOf(resultSet.getString("off_weapon_type"));
				int time = resultSet.getInt("time");
				WeaponTypeWrapper weapon = new WeaponTypeWrapper(weaponType, offweaponType);
				if (!motiontimes.containsKey(name))
					motiontimes.put(name, new MotionTime());
				MotionTime motion = motiontimes.get(name);
				if (!motion.containsKey(race))
					motion.put(race, new Job());
				Job job = motion.getJob(race);
				if (!job.containsKey(gender))
					job.put(gender, new ClassTime());
				ClassTime ct = job.getTimes(gender);
				if (!ct.containsKey(playerClass))
					ct.put(playerClass, new Times());
				Times times = ct.getTimes(playerClass);
				if (!times.containsKey(weapon))
					times.put(weapon, time);
			}
		}
		catch (Exception e) {
			log.error("" + e);
		}
		finally {
			DatabaseFactory.close(stmt, con);
		}
		return motiontimes;
	}

	@Override
	public void insertTime(String name, Race race, Gender gender, PlayerClass playerClass, WeaponTypeWrapper weapon, int time) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement(INSERT_QUERY);
			stmt.setString(1, name);
			stmt.setString(2, race.toString());
			stmt.setString(3, gender.toString());
			stmt.setString(4, playerClass.toString());
			stmt.setString(5, weapon.getMainHand() == null ? "NONE" : weapon.getMainHand().toString());
			stmt.setString(6, weapon.getOffHand() == null ? "NONE" : weapon.getOffHand().toString());
			stmt.setInt(7, time);
			stmt.execute();
			stmt.close();
		}
		catch (Exception e) {
			log.error("add error!" + e.getMessage());
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public void storeTime(String name, Race race, Gender gender, PlayerClass playerClass, WeaponTypeWrapper weapon, int Time) {
		Connection conn = null;
		try {
			conn = DatabaseFactory.getConnection();
			PreparedStatement stmt = conn.prepareStatement(UPDATE_QUERY);
			stmt.setInt(1, Time);
			stmt.setString(2, name);
			stmt.setString(3, race.toString());
			stmt.setString(4, gender.toString());
			stmt.setString(5, playerClass.toString());
			stmt.setString(6, weapon.getMainHand() == null ? "NONE" : weapon.getMainHand().toString());
			stmt.setString(7, weapon.getOffHand() == null ? "NONE" : weapon.getOffHand().toString());
			stmt.executeUpdate();
			stmt.close();
		}
		catch(SQLException e) {
			log.error("updata motion error! " + e);
		}
		finally {
			DatabaseFactory.close(conn);
		}
	}
}
