/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.aionemu.commons.database.DB;
import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.commons.database.IUStH;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.dao.PlayerLunaCostDAO;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.luna.LunaCostInfo;

/**
 * @author 81002
 */
public class MySQL5PlayerLunaCostDAO extends PlayerLunaCostDAO {

	private static final Logger log = LoggerFactory.getLogger(MySQL5PlayerLunaCostDAO.class);
	
	private static final String SELECT_QUERY = "SELECT * FROM luna_cost WHERE player_id=?";
	
	private static final String DELETE_QUERY = "DELETE FROM luna_cost WHERE player_id=?";
	
	public static final String INSERT_QUERY = "INSERT INTO luna_cost (player_id, luna_cost, luna_index, skin_id, count, reset_time) VALUES (?, ?, ?, ?, ?, ?)";
	
	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public void loadLunaCost(Player player) {
		Connection con = null;
		PreparedStatement stmt = null;
		try {
			con = DatabaseFactory.getConnection();
			stmt = con.prepareStatement(SELECT_QUERY);
			stmt.setInt(1, player.getObjectId());
			ResultSet rset = stmt.executeQuery();
			while(rset.next()) {
				int cost_id = rset.getInt("luna_cost");
				int index = rset.getInt("luna_index");
				LunaCostInfo cost = new LunaCostInfo(cost_id, index);
				cost.setSkinTemplateId(rset.getInt("skin_id"));
				cost.setUseCount(rset.getInt("count"));
				cost.setResetTime(rset.getInt("reset_time"));
				if (cost.getResetTime() > 0 && cost.getResetTime() > (int)(System.currentTimeMillis() / 1000))
					player.getPlayerLunaList().AddLunaCost(cost);
			}
			rset.close();
		}
		catch (Exception ex) {
			log.error("" + ex);
		}
		finally {
			DatabaseFactory.close(stmt, con);
		}
	}
	
	private boolean store(final int object_id, final LunaCostInfo cost) {
		return DB.insertUpdate(INSERT_QUERY, new IUStH(){

			@Override
			public void handleInsertUpdate(PreparedStatement stmt) throws SQLException {
				stmt.setInt(1, object_id);
				stmt.setInt(2, cost.getCostId());
				stmt.setInt(3, cost.getIndex());
				stmt.setInt(4, cost.getSkinTemplateId());
				stmt.setInt(5, cost.getUseCount());
				stmt.setInt(6, cost.getResetTime());
				stmt.execute();
			}
		});
	}

	private boolean deleteLunaCost(final int object_id) {
		return DB.insertUpdate(DELETE_QUERY, new IUStH() {

			@Override
			public void handleInsertUpdate(PreparedStatement stmt) throws SQLException {
				stmt.setInt(1, object_id);
				stmt.execute();
			}
		});
	}
	
	@Override
	public void store(Player player) {
		
		deleteLunaCost(player.getObjectId());
		
		for(LunaCostInfo cost : player.getPlayerLunaList().getLunaCostInfos()) {
			if (cost.getResetTime() > 0 && cost.getResetTime() < (System.currentTimeMillis() / 1000))
				continue;
			store(player.getObjectId(), cost);
		}
	}
}
