/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.geoEngine.math.Vector3f;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Summon;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.templates.spawns.SpawnTemplate;
import com.aionemu.gameserver.spawnengine.SpawnEngine;
import com.aionemu.gameserver.world.geo.GeoService;

import ai.AggressiveNpcAI2;

/**
 * @author zxl001
 */
@AIName("custom_boss1")
public class CustomBoss1AI2 extends AggressiveNpcAI2 {
	
	private static int CUSTOM_EVENT_ID = 500;
	
	@Override
	protected void handleCustomEvent(int eventId, Object... args) {
		
		if (eventId == CUSTOM_EVENT_ID) {
			Creature creature = (Creature)args[0];
			Player player = null;
			
			if(creature instanceof Player)
				player = (Player) creature;
			else if (creature instanceof Summon)
				player = ((Summon)creature).getMaster();
			
			getSpawnTemplate().getSpawnBoss().reSpawn();
			
			getSpawnTemplate().getSpawnBoss().onDie(player);
			
			int box_id = getSpawnTemplate().getSpawnBoss().getBoxId();
			
			if (box_id == 0)
				return;
			
			int world = getOwner().getWorldId();
			float x = getOwner().getX() - 6;
			float y = getOwner().getY() - 6;
			int x2 = 0, y2 = 0;
			for (int a = 0; a < 3; a++) {
				for (int b = 0; b < 3; b++) {
					float x1 = x + x2;
					float y1 = y + y2;
					Vector3f closestCollision = GeoService.getInstance().getClosestCollision(getOwner(), x1, y1, getOwner().getZ(), false);
					SpawnTemplate template = SpawnEngine.addNewSingleTimeSpawn(world, box_id, closestCollision.getX(), closestCollision.getY(), closestCollision.getZ(), (byte)0);
					SpawnEngine.spawnObject(template, 1);
					y2 += 6;
				}
				y2 = 0;
				x2 += 6;
			}
		}
	}
	
	@Override
	protected void handleDied() {
		if (getSpawnTemplate().getSpawnBoss() != null) {
			getSpawnTemplate().getSpawnBoss().onMostAttack(getAggroList().getMostPlayerDamage());
		}
		super.handleDied();
	}
}
