/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import java.util.Arrays;
import java.util.List;

import ai.GeneralNpcAI2;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIALOG_WINDOW;
import com.aionemu.gameserver.services.BreachService;
import com.aionemu.gameserver.services.item.ItemPacketService;
import com.aionemu.gameserver.utils.PacketSendUtility;

/**
 * @author zxl001
 */
@AIName("custom_enchant_fun")
public class CustomEnchantFunAI2 extends GeneralNpcAI2 {

	private static List<Integer> itemids = Arrays.asList(
		100000000, 100000001, 100000002
		
		);

	@Override
	protected void handleDialogStart(Player player) {
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 10));
	}

	@Override
	public boolean onDialogSelect(Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		Item item = null;
		switch (dialogId) {
			case 10000:
				item = player.getEquipment().getMainHandWeapon();
				if (item == null)
					item = player.getEquipment().getComboWeapon();
				break;
			case 10001:
				item = player.getEquipment().getOffHandWeapon();
				break;
			case 10002:
				item = player.getEquipment().getTorsoItem();
				break;
			case 10003:
				item = player.getEquipment().getShoulderItem();
				break;
			case 10004:
				item = player.getEquipment().getPantsItem();
				break;
			case 10005:
				item = player.getEquipment().getGlovesItem();
				break;
			case 10006:
				item = player.getEquipment().getBootsItem();
				break;
			default:
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), dialogId));
				return true;
		}
		return AdvEnchant(player, item, lastPage);
	}

	boolean AdvEnchant(Player player, Item item, int lastPage) {

		if (item == null) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), lastPage + 1));
			return true;
		}
		
		if (!itemids.contains(item.getItemId())) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), lastPage + 5));
			return true;
		}
		
		// 20-25级强化等级和价格
		int minLevel = 20;
		int maxLevel = 25;
		int price = 1000;

		if (lastPage == 1352) {
			//25-30级强化等级和价格
			minLevel = 25;
			maxLevel = 30;
			price = 2000;
		}

		if (item.getEnchantLevel() >= maxLevel) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), lastPage + 2));
			return true;
		}

		if (item.getEnchantLevel() < minLevel) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), lastPage + 3));
			return true;
		}

		if (player.getInventory().getItemCountByItemId(186000200) < price) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 4762));
			return true;
		}

		item.setEnchantLevel(maxLevel);
		BreachService.setItemSkill(player, item, true);
		player.getGameStats().updateStatsVisually();
		player.getInventory().decreaseByItemId(186000200, price);
		ItemPacketService.updateItemAfterInfoChange(player, item);
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), lastPage + 4));
		return true;
	}
}
