/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import java.util.Calendar;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.ai2.NpcAI2;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIALOG_WINDOW;
import com.aionemu.gameserver.services.custom.LegionInstanceService;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author 81002
 */
@AIName("custom_legion_portal")
public class LegionInstancePortalAI2 extends NpcAI2 {

	@Override
	protected void handleDialogStart(Player player) {
		
		if (!checkTime()) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 10));
			return;
		}
		if (!player.isLegionMember()) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1352));
			return;
		}
		int legionId = player.getLegion().getLegionId();
		if (player.getLegionMember().isBrigadeGeneral()) {
			if (LegionInstanceService.getInstance().IsStart(legionId)) {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1353));
				return;
			}
			else {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1011));
				return;
			}
		}
		else {
			if (LegionInstanceService.getInstance().IsStart(legionId)) {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1353));
				return;
			}
			else {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1354));
				return;
			}
		}
	}
	
	@Override
	public boolean onDialogSelect(Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		switch(lastPage) {
			case 1011:
				if (dialogId == 10000) {
					if (!checkTime()) {
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1012));
						return true;
					}
					if (!player.getLegionMember().isBrigadeGeneral()) {
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1013));
						return true;
					}
					if (LegionInstanceService.getInstance().IsStart(player.getLegion().getLegionId())) {
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1014));
						return true;
					}
					LegionInstanceService.getInstance().StartLegionEvent(player.getLegion());
					PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1353));
					return true;
				}
				break;
			case 1353:
				if (dialogId == 10000) {
					if (!checkTime()) {
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1012));
						return true;
					}
					if (LegionInstanceService.getInstance().IsStart(player.getLegion().getLegionId())) {
						WorldMapInstance instance = LegionInstanceService.getInstance().getInstance(player.getLegion().getLegionId());
						InstanceService.registerPlayerWithInstance(instance, player);
						TeleportService2.teleportTo(player, instance.getMapId(), instance.getInstanceId(), 354.7868f, 349.3457f, 96.091f, (byte) 0, TeleportAnimation.BEAM_ANIMATION);
						return true;
					}
					else {
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1354));
						return true;
					}
				}
				break;
		}
		return true;
	}
	
	private boolean checkTime() {
		Calendar calendar = Calendar.getInstance();
		int hour = calendar.get(Calendar.HOUR_OF_DAY);
		if (hour >= 19 && hour < 20 || hour >= 22 && hour < 23)
			return true;
		return false;
	}
}
