/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import com.aionemu.commons.utils.i18n.CustomMessageId;
import com.aionemu.commons.utils.i18n.LanguageHandler;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.ai2.NpcAI2;
import com.aionemu.gameserver.configs.main.WeddingsConfig;
import com.aionemu.gameserver.model.Gender;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.gameobjects.player.RequestResponseHandler;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIALOG_WINDOW;
import com.aionemu.gameserver.network.aion.serverpackets.SM_PLAYER_INFO;
import com.aionemu.gameserver.network.aion.serverpackets.SM_QUESTION_WINDOW;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.services.WeddingService;
import com.aionemu.gameserver.utils.PacketSendUtility;

/**
 * @author zxl001
 */
@AIName("marriage")
public class MarriageAI2 extends NpcAI2 {
	
	@Override
	protected void handleDialogStart(Player player) {
		if (player.isMarried())
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1011));
		else 
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 10));
	}
	
	@Override
	public boolean onDialogSelect(Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		QuestEnv env = new QuestEnv(getOwner(), player, questId, dialogId);
		QuestDialog dialog = env.getDialog();
		switch (dialog.id()) {
			case 10000:
				if (player.findPartner() == null) {
					if (player.getGender() == Gender.FEMALE)
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1012));
					else 
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1013));
				}
				else {
					PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 0));
					sendResquest(player);
				}
				break;
			case 10001:
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 0));
				unWedding(player);
				break;
		}
		return true;
	}
	
	private void unWedding(Player player) {
		Player marry = player.findPartner();
		if (marry == null || !marry.isOnline()) {
			Item item = player.getInventory().getFirstItemByItemId(WeddingsConfig.WEDDINGS_GIFT);
			if (item != null)
				player.getInventory().delete(item);
			PacketSendUtility.sendMessage(player, LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE36));
			player.setPartner(null);
			PacketSendUtility.broadcastPacket(player, new SM_PLAYER_INFO(player, true));
		}
		else {
			WeddingService.getInstance().unDoWedding(player, marry);
			PacketSendUtility.sendMessage(marry, LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE36));
		}
	}
	
	private void sendResquest(final Player player) {
		final Player marry = player.findPartner();
		if (marry == null || !marry.isOnline())
			return;
		String msg = "";
		if (player.getGender() == Gender.FEMALE)
			msg += LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE38);
		else 
			msg += LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE39);
		
		RequestResponseHandler requests = new RequestResponseHandler(player) {

			@Override
			public void acceptRequest(Creature requester, Player responder) {
				WeddingService.getInstance().unDoWedding(player, marry);
				PacketSendUtility.sendMessage(player, LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE37));
				PacketSendUtility.sendMessage(marry, LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE37));
			}

			@Override
			public void denyRequest(Creature requester, Player responder) {
				PacketSendUtility.sendMessage(player, LanguageHandler.translate(CustomMessageId.MARRY_MESSAGE40));
			}
		};
		if (marry.getResponseRequester().putRequest(1403000, requests))
			PacketSendUtility.sendPacket(marry, new SM_QUESTION_WINDOW(1403000, marry.getObjectId(), 0, msg));
	}
}
