/*
 * This file is part of Aion-Finish <Aion-Finish.org>
 *
 * Aion-Finish is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Aion-Finish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Aion-Finish. If not, see <http://www.gnu.org/licenses/>.
 */
package ai.instance.SteelRoseQuarters;

import java.util.concurrent.Future;

import ai.AggressiveNpcAI2;

import com.aionemu.commons.network.util.ThreadPoolManager;
import com.aionemu.commons.utils.Rnd;

import com.aionemu.gameserver.ai2.AI2Actions;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.ai2.poll.AIAnswer;
import com.aionemu.gameserver.ai2.poll.AIAnswers;
import com.aionemu.gameserver.ai2.poll.AIQuestion;
import com.aionemu.gameserver.skillengine.SkillEngine;

/**
 * Author zxl001
 **/
@AIName("walkingtalkingbomb")
public class WalkingTalkingBombAI2 extends AggressiveNpcAI2 {
	
	private Future<?> task;
	
	@Override
	protected void handleSpawned() {
		super.handleSpawned();
		doSchedule();
	}

	final int skillid = Rnd.get(10) == 0 ? 19708 : 21314;
	
	private void doSchedule() {
		
		task = ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				if (!isAlreadyDead()) {
					
					SkillEngine.getInstance().getSkill(getOwner(), skillid, 55, getOwner().getTarget()).useNoAnimationSkill();
					task = ThreadPoolManager.getInstance().schedule(new Runnable() {

						@Override
						public void run() {
							despawn();
						}
					}, 4000);
				}
			}
		}, 4000);
	}

	@Override
	public AIAnswer ask(AIQuestion question) {
		switch (question) {
			case CAN_RESIST_ABNORMAL:
				return AIAnswers.POSITIVE;
			default:
				return AIAnswers.NEGATIVE;
		}
	}

	@Override
	protected AIAnswer pollInstance(AIQuestion question) {
		switch (question) {
			case SHOULD_DECAY:
				return AIAnswers.NEGATIVE;
			case SHOULD_RESPAWN:
				return AIAnswers.NEGATIVE;
			case SHOULD_REWARD:
				return AIAnswers.NEGATIVE;
			default:
				return null;
		}
	}
	
	@Override
	protected void handleDied() {
		if (task != null)
			task.cancel(true);
	}

	private void despawn() {
		if (!isAlreadyDead())
			AI2Actions.killSilently(this, getOwner());
		AI2Actions.deleteOwner(this);
	}
}
