/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.instance.sauroSupplyBase;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;

import ai.GeneralNpcAI2;

/**
 * @author zxl001
 */
@AIName("west_tower")
public class WestTowerAI2 extends GeneralNpcAI2 {

	protected List<Integer> percents = new ArrayList<Integer>();

	@Override
	protected void handleAttack(Creature creature) {
		super.handleAttack(creature);
		checkPercentage(getLifeStats().getHpPercentage());
	}

	private void addPercent() {
		percents.clear();
		Collections.addAll(percents, new Integer[] { 75, 50, 25 });
	}

	private synchronized void checkPercentage(int hpPercentage) {
		if (percents.size() > 0) {
			int index = percents.indexOf(hpPercentage);
			if (index != -1) {
				percents.remove(percents.indexOf(hpPercentage));
				spawnToAttackTarget();
			}
		}
	}

	private void spawnToAttackTarget() {
		Npc obj = (Npc) spawn(284435, 906.5448f, 874.1216f, 411.32877f, (byte) 30);
		obj.setTarget(getOwner().getTarget());
		obj.getMoveController().moveToTargetObject();
		obj = (Npc) spawn(284435, 888.7703f, 877.628f, 411.45676f, (byte) 15);
		obj.setTarget(getOwner().getTarget());
		obj.getMoveController().moveToTargetObject();
		obj = (Npc) spawn(284435, 889.452f, 899.64386f, 411.45676f, (byte) 105);
		obj.setTarget(getOwner().getTarget());
		obj.getMoveController().moveToTargetObject();
		obj = (Npc) spawn(284435, 906.4602f, 905.6901f, 411.32886f, (byte) 90);
		obj.setTarget(getOwner().getTarget());
		obj.getMoveController().moveToTargetObject();
	}

	@Override
	protected void handleSpawned() {
		super.handleSpawned();
		addPercent();
	}

	@Override
	protected void handleDespawned() {
		super.handleDespawned();
		percents.clear();
	}

	@Override
	protected void handleDied() {
		percents.clear();
		super.handleDied();
	}
}
