/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.worlds;

import javolution.util.FastMap;
import ai.GeneralNpcAI2;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.controllers.observer.AttackObserver;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.CreatureType;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_CUSTOM_SETTINGS;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.world.World;

/**
 * @author zxl001
 */
@AIName("defenattack")
public class DefenAttack extends GeneralNpcAI2 {

	private FastMap<Integer, AttackObserver> observed = new FastMap<Integer, AttackObserver>().shared();
	private boolean isAttack = false;
  private int SRANGE = 30;
  
  /*@Override
	protected void handleSpawned() {
  	SRANGE = getObjectTemplate().getAggroRange();
  }*/
  
	@Override
	protected void handleCreatureMoved(Creature creature) {
		if (creature instanceof Player) {
			final Player player = (Player) creature;
			if (!creature.getLifeStats().isAlreadyDead() && isInRange(creature, SRANGE)) {
				final AttackObserver observer = new AttackObserver() {

					@Override
					public void attacked() {
						if (!isAttack) {
							getOwner().setNpcType(CreatureType.ATTACKABLE.getId());
							sendAttackSetting(player);
							isAttack = true;
						}
					}
				};
				if (!observed.containsKey(player.getObjectId())) {
					player.getObserveController().addObserver(observer);
					observed.put(player.getObjectId(), observer);
				}
			}
		}
	}

	private void sendAttackSetting(final Creature creature) {
		Player player = (Player) creature;
		if (player != null) {
			PacketSendUtility.sendPacket(player, new SM_CUSTOM_SETTINGS(getObjectId(), 0, 0, 0));
			PacketSendUtility.sendPacket(player, new SM_CUSTOM_SETTINGS(getObjectId(), 2, 1, 0));
			this.handleAttack(creature);
		}
	}

	@Override
	protected void handleCreatureNotSee(Creature creature) {
		if (creature instanceof Player) {
			Player player = (Player) creature;
			AttackObserver obj = observed.remove(player.getObjectId());
			if (obj != null)
				player.getObserveController().removeObserver(obj);
		}
	}

	@Override
	protected void handleAttack(final Creature creature) {
		SkillEngine.getInstance().getSkill(getOwner(), 20672, 65, creature).useNoAnimationSkill();
		SkillEngine.getInstance().getSkill(getOwner(), 21263, 65, creature).useNoAnimationSkill();
		isAttack = false;
	}

	@Override
	protected void handleBackHome() {
		isAttack = false;
		getOwner().setNpcType(CreatureType.FRIEND.getId());
		for (Integer objId : observed.keySet()) {
			Player player = World.getInstance().findPlayer(objId);
			player.getObserveController().removeObserver(observed.get(objId));
			PacketSendUtility.sendPacket(player, new SM_CUSTOM_SETTINGS(getOwner().getObjectId(), 0, 38, 0));
			PacketSendUtility.sendPacket(player, new SM_EMOTION(getOwner(), EmotionType.NEUTRALMODE));
		}
		observed.clear();
	}
}
