/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.worlds;

import java.util.Iterator;

import com.aionemu.commons.utils.i18n.CustomMessageId;
import com.aionemu.commons.utils.i18n.LanguageHandler;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.templates.spawns.SpawnTemplate;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.questEngine.QuestEngine;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.spawnengine.SpawnEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.World;

import ai.GeneralNpcAI2;

/**
 * @author zxl001
 */
@AIName("summoning_stone")
public class SummoningStoneAI2 extends GeneralNpcAI2 {
	
	@Override
	protected void handleDialogStart(Player player) {
		super.handleDialogStart(player);
	}
	
	@Override
	public boolean onDialogSelect(final Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		QuestEnv env = new QuestEnv(getOwner(), player, questId, dialogId);
		env.setExtendedRewardIndex(extendedRewardIndex);
		
		if (QuestEngine.getInstance().onDialog(env)) {
			return true;
		}
		
		if (dialogId == 10000) {
			boolean hasItem = player.getInventory().getFirstItemByItemId(185000216) != null;
			if (!hasItem) {
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402539));
				return false;
			}
			else if (player.getInventory().decreaseByItemId(185000216, 1)) {
				
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402541));
				
				spawnSchedule(player);
				
				Iterator<Player> iter = World.getInstance().getPlayersIterator();
				String race = "";
				if (player.getRace() == Race.ASMODIANS) 
					race = LanguageHandler.translate(CustomMessageId.PLAYERRACE_ASMOS);
				else
					race = LanguageHandler.translate(CustomMessageId.PLAYERRACE_ELYOS);
				
				while (iter.hasNext()) {
					Player target = (Player) iter.next();
					String loc = "[pos:" + LanguageHandler.translate(CustomMessageId.PVPKILLS_WORLD) + ";" + target.getRace().getRaceId() + " " + player.getWorldId() + " " + player.getX()	+ " " + player.getY() + " 0.0 0]";
					//PacketSendUtility.sendBrightYellowMessageOnCenter(target, race + "玩家" + player.getName() + "召唤了古代怪物，将在60秒后在" + loc + "刷新");
				}
			}
		}
		return true;
	}
	
	private void spawnSchedule(final Player player) {
		
		ThreadPoolManager.getInstance().schedule(new Runnable() {
			
			@Override
			public void run() {
				PacketSendUtility.broadcastPacketAndReceive(player, new SM_SYSTEM_MESSAGE(1402540));
				SpawnTemplate template = SpawnEngine.addNewSingleTimeSpawn(player.getWorldId(), 855263, player.getX(), player.getY(), player.getZ(), (byte)0);
				SpawnEngine.spawnObject(template, player.getInstanceId());
			}
		}, 60000);
	}
}
