/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package gameuicommands;

import java.io.IOException;

import com.aionemu.gameserver.dataholders.DataManager;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.VisibleObject;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.templates.NamePath;
import com.aionemu.gameserver.model.templates.PathType;
import com.aionemu.gameserver.model.templates.spawns.SpawnTemplate;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.item.ItemService.ItemAddPredicate;
import com.aionemu.gameserver.spawnengine.SpawnEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.chathandlers.GameUICommand;

/**
 * @author zxl001
 */
public class Wish extends GameUICommand {

	/**
	 * @param alias
	 */
	public Wish() {
		super("wish");
	}

	@Override
	public void execute(final Player player, String... params) {
		int count = 1;
		NamePath items = DataManager.NAME_PATH_DATA.getNamePathForTypeId(PathType.ITEM.getId());
		NamePath npcs = DataManager.NAME_PATH_DATA.getNamePathForTypeId(PathType.NPC.getId());
		int itemId = 0;
		if (params.length == 1) {
			if (items.getObjectId(params[0].toUpperCase()) > 0) {
				itemId = items.getObjectId(params[0].toUpperCase());
				ItemService.addItem(player, itemId, 1);
				return;
			}
			else if (npcs.getObjectId(params[0].toUpperCase()) > 0) {
				SpawnTemplate spawn = SpawnEngine.addNewSpawn(player.getWorldId(), npcs.getObjectId(params[0].toUpperCase()), player.getX(), player.getY(), player.getZ(), player.getHeading(), 295);
				if (spawn != null) {
					VisibleObject visibleObject = SpawnEngine.spawnObject(spawn, player.getInstanceId());
					try {
						DataManager.SPAWNS_DATA2.saveSpawn(player, visibleObject, false);
					}
					catch (IOException e) {
						e.printStackTrace();
						PacketSendUtility.sendMessage(player, "Could not save spawn");
					}
				}
			}
		}
		else if (params.length == 2) {
			VisibleObject target = player.getTarget();
			if (target == null)
				target = player;
			if (!(target instanceof Player))
				target = player;
			Player targetPlayer = (Player) target;
			
			try {
				count = Integer.parseInt(params[0]);
				itemId = items.getObjectId(params[1].toUpperCase());
				ItemService.addItem(targetPlayer, itemId, count);
				return;
			}
			catch (Exception e) {
				final int enchantLevel = Integer.parseInt(params[1]);
				itemId = items.getObjectId(params[0].toUpperCase());
				ItemService.addItem(targetPlayer, itemId, 1, new ItemAddPredicate() {

					@Override
					public boolean apply(Item item) {
						if (item.getItemTemplate().getAuthorize() > 0)
							item.setAuthorize(enchantLevel);
						else
							item.setEnchantLevel(enchantLevel);
						return true;
					}
				});
			}
			if (player.isGM())
				PacketSendUtility.sendMessage(player, "itemId: " + itemId);
			PacketSendUtility.sendMessage(player, "add item to : " + targetPlayer.getName());
		}
	}
}
