/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.Map;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author 81002
 */
@InstanceID(MapID = 300610000, InstanceMaskID = 0)
public class Instance_300610000 extends GeneralInstanceHandler {

	private boolean newInstance = true;
	private int killCount = 0;
	private Map<Integer, StaticDoor> doors;

	@Override
	public void onDie(Npc npc) {
		int npcId = npc.getNpcId();
		switch (npcId) {
			case 236074:
			case 236075:
			case 236076:
				killCount++;
				if (killCount == 15) {
					killCount = 0;
					onOpenDoor(457);
					PacketSendUtility.sendPacket(instance.getPlayersInside().get(0), new SM_SYSTEM_MESSAGE(1402781));
				}
				break;
			case 236077:
			case 236078:
			case 236079:
				killCount++;
				if (killCount == 15) {
					onOpenDoor(64);
					PacketSendUtility.sendPacket(instance.getPlayersInside().get(0), new SM_SYSTEM_MESSAGE(1402781));
				}
				break;
			case 236304:
				onOpenDoor(118);
				PacketSendUtility.sendPacket(instance.getPlayersInside().get(0), new SM_SYSTEM_MESSAGE(1402781));
				break;
			case 236306:
				spawn(730445, 619.643f, 685.1399f, 522.0487f, (byte)80);
				break;
		}
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		doors = instance.getDoors();
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		int npcId = npc.getNpcId();
		switch (npcId) {
			case 702675:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn1();
				break;
			case 702674:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn2();
				break;
			case 702673:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn3();
				break;
			case 702691:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn4();
				break;
			case 702692:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn5();
				break;
			case 702690:
				npc.getController().delete();
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402780));
				spawn6();
				break;
		}
	}

	private void spawn6() {
		spawn(236077, 985.2942f, 882.7517f, 762.5121f, (byte) 105);
		spawn(236077, 987.7971f, 884.1927f, 762.5577f, (byte) 100);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236077, 995.7424f, 874.3123f, 762.5577f, (byte) 30);
				spawn(236077, 996.8099f, 876.8442f, 762.5577f, (byte) 66);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236077, 991.4525f, 877.5563f, 762.5577f, (byte) 24);
			}
		}, 10000);
	}

	private void spawn5() {
		spawn(236078, 996.4833f, 902.6909f, 762.5577f, (byte) 76);
		spawn(236078, 999.2430f, 900.2877f, 762.5577f, (byte) 76);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236077, 991.5158f, 899.8228f, 762.5577f, (byte) 105);
				spawn(236077, 991.5474f, 894.6733f, 762.5577f, (byte) 15);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236079, 994.3097f, 898.9786f, 762.5577f, (byte) 105);
			}
		}, 10000);
	}

	private void spawn4() {
		spawn(236078, 1003.1717f, 888.0419f, 762.8908f, (byte) 15);
		spawn(236078, 1000.0642f, 890.5679f, 762.8908f, (byte) 15);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236078, 1001.002f, 896.0778f, 762.5577f, (byte) 105);
				spawn(236078, 1009.7108f, 890.2547f, 762.5577f, (byte) 45);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236078, 1008.5347f, 893.6851f, 762.5577f, (byte) 76);
			}
		}, 10000);
	}

	private void spawn3() {
		spawn(236074, 962.9276f, 795.8439f, 734.6989f, (byte) 93);
		spawn(236074, 967.5338f, 793.4503f, 734.046f, (byte) 66);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236074, 967.8346f, 787.9694f, 734.0461f, (byte) 8);
				spawn(236074, 963.3557f, 784.2463f, 734.046f, (byte) 26);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236074, 961.4771f, 790.228f, 734.046f, (byte) 66);
			}
		}, 10000);
	}

	private void spawn2() {
		spawn(236075, 970.5629f, 779.24f, 734.0548f, (byte) 66);
		spawn(236075, 971.4633f, 775.5289f, 734.0187f, (byte) 66);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236075, 953.5185f, 772.9017f, 734.0548f, (byte) 8);
				spawn(236075, 954.2308f, 770.0457f, 734.0548f, (byte) 8);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236075, 963.4158f, 772.5471f, 734.0549f, (byte) 36);
			}
		}, 10000);
	}

	private void spawn1() {
		spawn(236074, 946.0414f, 778.3027f, 734.0187f, (byte) 66);
		spawn(236074, 947.1217f, 775.2617f, 734.0187f, (byte) 66);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236075, 947.6798f, 769.5505f, 734.0548f, (byte) 30);
				spawn(236075, 943.3198f, 781.9261f, 734.0187f, (byte) 90);
			}
		}, 5000);
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawn(236076, 942.0587f, 776.4103f, 734.0187f, (byte) 0);
			}
		}, 10000);
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (newInstance) {
			int npcId = player.getRace() == Race.ASMODIANS ? 206396 : 206380;
			spawn(npcId, 818.04f, 932.1826f, 1207.431f, (byte) 13);
			newInstance = false;
		}
	}
}
