/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.controllers.effect.PlayerEffectController;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author zxl001
 */
@InstanceID(MapID = 300590000, InstanceMaskID = 314)
public class OphidanBridgeInstance extends GeneralInstanceHandler {

	private int Powerdevice;
	private Map<Integer, StaticDoor> doors;
	private Race instanceRace;
	private Future<?> failTask;

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		spawn(instanceRace == Race.ELYOS ? 701646 : 701647, 763.51685f, 533.11804f, 576.5853f, (byte) 59);
		spawn(instanceRace == Race.ELYOS ? 801763 : 801765, 740.7189f, 536.31616f, 575.6878f, (byte) 1);
		doors = instance.getDoors();
		Npc vera = instance.getNpc(231050);
		SkillEngine.getInstance().getSkill(vera, 21438, 60, vera).useNoAnimationSkill();
	}

	@Override
	public void onDie(Npc npc) {
		switch (npc.getNpcId()) {
			case 230413: // 1 Generator
				sendMsg(1401904);
				spawn(230417, 666.6502f, 474.34778f, 601.1673f, (byte) 37);
				despawnNpc(npc);
				Powerdevice++;
				if (Powerdevice == 4) {
					spawn(701644, 435.42862f, 496.41296f, 604.8871f, (byte) 1);
				}
				break;
			case 230414: // 2 Generator
				sendMsg(1401905);
				despawnNpc(npc);
				spawn(230418, 524.34784f, 427.49088f, 621.8206f, (byte) 56);
				Powerdevice++;
				if (Powerdevice == 4) {
					spawn(701644, 435.42862f, 496.41296f, 604.8871f, (byte) 1);
				}
				break;
			case 230415: // 3 Generator
				sendMsg(1401906);
				despawnNpc(npc);
				spawn(230419, 602.56036f, 556.3219f, 592.16406f, (byte) 33);
				Powerdevice++;
				if (Powerdevice == 4) {
					spawn(701644, 435.42862f, 496.41296f, 604.8871f, (byte) 1);
				}
				break;
			case 230416: // 4 Generator
				sendMsg(1401907);
				despawnNpc(npc);
				spawn(230420, 476.8503f, 523.8022f, 598.8186f, (byte) 54);
				Powerdevice++;
				if (Powerdevice == 4) {
					spawn(701644, 435.42862f, 496.41296f, 604.8871f, (byte) 1);
				}
				break;
			case 231050: // bombard
				if (failTask != null && !failTask.isDone()) {
					failTask.cancel(true);
				}
				spawn(730868, 350.18478f, 490.73065f, 606.34015f, (byte) 1);
				break;
			case 233320:
				despawnNpc(npc);
				startFinalTimer();
				break;
		}
	}

	private void startFinalTimer() {
		sendMsg(1401892);// start message for timer
		this.sendMessage(1401875, 15 * 60 * 1000); // 10 minutes before firing
		this.sendMessage(1401876, 20 * 60 * 1000); // 5 minutes before firing
		this.sendMessage(1401877, 24 * 60 * 1000); // 1 minutes before firing

		failTask = ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				sendMsg(1401878); // Report a charged gun bombard
				final Npc vera1 = instance.getNpc(231050);// bombard
				if (vera1 != null) {
					SkillEngine.getInstance().getSkill(vera1, 21442, 60, vera1).useNoAnimationSkill();/* Бомбануло))) */
				}
			}
		}, 150000);
	}

	private void sendMessage(final int msgId, long delay) {
		if (delay == 0) {
			this.sendMsg(msgId);
		}
		else {
			ThreadPoolManager.getInstance().schedule(new Runnable() {

				public void run() {
					sendMsg(msgId);
				}
			}, delay);
		}
	}

	private void removeEffects(Player player) {
		PlayerEffectController effectController = player.getEffectController();
		effectController.removeEffect(21434);
		effectController.removeEffect(21435);
	}

	@Override
	public void onLeaveInstance(Player player) {
		removeEffects(player);
	}

	@Override
	public void onPlayerLogOut(Player player) {
		removeEffects(player);
	}

	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}

	@Override
	public void onInstanceDestroy() {
		doors.clear();
	}

	@Override
	public boolean onDie(final Player player, Creature lastAttacker) {
		PacketSendUtility.broadcastPacket(player, new SM_EMOTION(player, EmotionType.DIE, 0, player.equals(lastAttacker) ? 0 : lastAttacker.getObjectId()), true);
		PacketSendUtility.sendPacket(player, new SM_DIE(player.haveSelfRezEffect(), player.haveSelfRezItem(), 0, 8));
		return true;
	}

	@Override
	public void onEnterInstance(Player player) {
		if (instanceRace == null) {
			instanceRace = player.getRace();
		}
	}
}
