/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.eventinstance;

import instance.pvparenas.ChaosTrainingGroundsInstance;

import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.playerreward.InstancePlayerReward;
import com.aionemu.gameserver.model.instance.playerreward.PvPArenaPlayerReward;
import com.aionemu.gameserver.services.custom.EventType;
import com.aionemu.gameserver.services.instance.DredgionService2;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author 午夜
 * 自定义1vs1PVP活动副本
 */
@InstanceID(MapID = 300360000, InstanceMaskID = 800)
public class Custom1vs1PVPInstance extends ChaosTrainingGroundsInstance {
	
	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		killBonus = 1000; // 每次击杀增加点数
		deathFine = -125; // 每次死亡额外减少点数
		super.onInstanceCreate(instance);
	}
	
	@Override
	protected void reward() {
		instanceReward.setCustomReward(true);
		for (InstancePlayerReward playerReward : instanceReward.getInstanceRewards()) {
			PvPArenaPlayerReward reward = (PvPArenaPlayerReward) playerReward;
			if (!reward.isRewarded()) {
				int score = reward.getScorePoints();
				int rank = instanceReward.getRank(score);
				float percent = reward.getParticipation();
				//AP奖励
				int basicAP = 2000; // AP基础奖励
				int rankingAP = (int)((10-rank) * 100 * percent);
				int scoreAP = (int)((score - 13000) * percent);
				reward.setBasicAP(basicAP);
				reward.setRankingAP(rankingAP);
				reward.setScoreAP(scoreAP);
				//GP奖励
				int basicGP = 100;
				int rankingGP = (int)((5-rank) * 10 * percent);
				int scoreGP = (int)(((score - 13000) / 100) * percent);
				reward.setBasicGP(basicGP);
				reward.setRankingGP(rankingGP);
				reward.setScoreGP(scoreGP);
				// 额外奖励
				reward.setMesalItemId1(166020000);
				if (rank == 0)
					reward.setMesalItemId1(166030005);
				reward.setMedalItem1(1);
			}
		}
		super.reward();
	}
	
	@Override
	public void onEnterInstance(Player player) {
		super.onEnterInstance(player);
		player.getEventInfo().AddCount(EventType.Event_1vs1);
	}
	
	@Override
	public void onLeaveInstance(Player player) {
		super.onLeaveInstance(player);
		if (player.getEventInfo().checkCount(EventType.Event_1vs1))
			DredgionService2.getInstance().onPlayerLogin(player);
		//player.getEventInfo().reset();
	}
	
	//@Override
	//public void onStopTraining(Player player) {
	//}
}
