/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.eventinstance;

import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.playerreward.HarmonyGroupReward;
import com.aionemu.gameserver.services.custom.EventType;
import com.aionemu.gameserver.services.instance.DredgionService2;
import com.aionemu.gameserver.world.WorldMapInstance;

import instance.pvparenas.HaramoniousTrainingCenterInstance;

/**
 * @author 午夜
 * 自定义3vs3PVP活动副本
 */
@InstanceID(MapID = 300450000, InstanceMaskID = 801)
public class Custom3vs3PVPInstance extends HaramoniousTrainingCenterInstance {
	
	@Override
	public void onInstanceCreate(final WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		killBonus = 3000;
		deathFine = -300;
	}

	@Override
	protected void reward() {
		instanceReward.setCustomReward(true);
		int totalPoints = instanceReward.getTotalPoints();
		for (HarmonyGroupReward group : instanceReward.getGroups()) {
			int score = group.getPoints();
			int rank = instanceReward.getRank(score);
			float percent = score / totalPoints;
			int basicAP = 2000;
			int rankingAP = (int)((10-rank) * 100 * percent);
			int scoreAP = (int)((score - 13000) / 10 * percent);
			if (scoreAP > 0)
				scoreAP = 0;
			group.setBasicAP(basicAP);
			group.setRankingAP(rankingAP);
			group.setScoreAP(scoreAP);
			int basicGP = 100;
			int rankingGP = (int)((5-rank) * 10 * percent);
			int scoreGP = (int)(((score - 13000) / 100) * percent);
			if (scoreGP < 0)
				scoreGP = 0;
			group.setBasicGP(basicGP);
			group.setRankingGP(rankingGP);
			group.setScoreGP(scoreGP);
			int baseCash = 200;
			int rankCash = (int)((10-rank) * 10 * percent);
			int scoreCash = (int)((score - 13000) / 200 * percent);
			if (scoreCash < 0)
				scoreCash = 0;
			group.setRewardItemId1(186000230);
			group.setBasicItem1(baseCash);
			group.setRankingItem1(rankCash);
			group.setScoreItem1(scoreCash);
			if (rank == 0)
				group.setMesalItemId1(166030007);
			else 
				group.setMesalItemId1(166020000);
			group.setMedalItem1(4);
		}
		super.reward();
	}
	
	@Override
	public void onEnterInstance(Player player) {
		super.onEnterInstance(player);
		player.getEventInfo().AddCount(EventType.Event_3vs3);
	}
	
	@Override
	public void onLeaveInstance(Player player) {
		super.onLeaveInstance(player);
		if (player.getEventInfo().checkCount(EventType.Event_3vs3))
			DredgionService2.getInstance().onPlayerLogin(player);
	}
}
