/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.eventinstance;

import java.util.ArrayList;
import java.util.concurrent.Future;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.services.custom.LegionInstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author zxl001
 */
@InstanceID(MapID = 300300000, InstanceMaskID = 810)
public class CustomLegionInstance extends GeneralInstanceHandler {
	
	private ArrayList<Npc> npcs = new ArrayList<Npc>();
	
	private int CUSTOM_EVENT_ID = 810;
	private int RUN_TIME = 60;
	private Future<?> instanceTask;
	
	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		spawn(810401, 345.25107f, 349.40176f, 96.09097f, (byte) 0);
	}
	
	@Override
	public void onCustomEventHandler(int eventId, Object... objects) {
		if (eventId == CUSTOM_EVENT_ID) {
			Player player = (Player) objects[0];
			LegionInstanceService.getInstance().StartEvent(player.getLegion().getLegionId());
			sp(810108, 345.25107f, 349.40176f, 96.09097f, (byte) 0);
			startInstanceTask();
		}
	}
	
	private void startInstanceTask() {
		instanceTask = ThreadPoolManager.getInstance().schedule(new Runnable() {
			
			@Override
			public void run() {
				
				for(Npc npc : instance.getNpcs()) {
					npc.getController().delete();
				}
				
				instance.doOnAllPlayers(new Visitor<Player>() {
					
					@Override
					public void visit(Player object) {
						PacketSendUtility.sendMessage(object, "time end!");
					}
				});
			}
		}, RUN_TIME * 60 * 1000);
	}
	
	private void sp(int npcId, float x, float y, float z, byte h) {
		Npc npc = (Npc) spawn(npcId, x, y, z, h);
		npcs.add(npc);
	}
	
	@Override
	public void onDie(Npc npc) {
		if (npcs.contains(npc))
			npcs.remove(npc);
		
		switch(npc.getNpcId()) {
			case 810108:
				if (npcs.size() == 0) {
					ThreadPoolManager.getInstance().schedule(new Runnable() {
						
						@Override
						public void run() {
							sp(0, 0f, 0f, 0f, (byte)0);
						}
					}, 60 * 1000);
					sendMessage("下一波怪物将在 60 秒后刷新");
				}
				break;
		}
	}
	
	private void sendMessage(final String msg) {
		instance.doOnAllPlayers(new Visitor<Player>() {
			
			@Override
			public void visit(Player object) {
				PacketSendUtility.sendMessage(object, msg);
			}
		});
	}
	
	@Override
	public boolean onDie(Player player, Creature lastAttacker) {
		PacketSendUtility.broadcastPacket(player, new SM_EMOTION(player, EmotionType.DIE, 0, player.equals(lastAttacker) ? 0 : lastAttacker.getObjectId()), true);
		PacketSendUtility.sendPacket(player, new SM_DIE(false, false, 0, 8));
		return true;
	}
	
	@Override
	public void onExitInstance(Player player) {
		if (player.getRace() == Race.ASMODIANS) {
			TeleportService2.teleportTo(player, 120010000, 0, 0, 0, (byte)0, TeleportAnimation.BEAM_ANIMATION);
		}
		else {
			TeleportService2.teleportTo(player, 110010000, 0, 0, 0, (byte)0, TeleportAnimation.BEAM_ANIMATION);
		}
	}
}
