/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.kamarbattlefield;

import java.util.ArrayList;
import java.util.List;

import com.aionemu.gameserver.controllers.effect.PlayerEffectController;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.actions.NpcActions;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_PLAY_MOVIE;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;

/**
 * @author Ranastic
 */
@InstanceID(MapID = 301120000, InstanceMaskID = 107)
public class Kamar_Battlefield extends Kamar_Battlefield_Controller
{
	private List<Integer> movies = new ArrayList<Integer>();

	@Override
	public void onEnterInstance(Player player) {
		if (isInstanceStarted.compareAndSet(false, true)) {
			startInstanceTask();
		}
		super.onEnterInstance(player);
		switch (player.getRace()) {
		case ELYOS:
			//sendMovie(player, 27);
			break;
		case ASMODIANS:
			//sendMovie(player, 27);
			break;
		}
	}

	@Override
	public void onDie(Npc npc) {
		Player mostPlayerDamage = npc.getAggroList().getMostPlayerDamage();
		if (mostPlayerDamage == null) {
			return;
		}
		switch (npc.getObjectTemplate().getTemplateId()) {
		case 000000:
			updateScore(mostPlayerDamage, npc, 200, false);
			return;
		case 000001:
			if (!kamarBattlefieldReward.isRewarded()) {
				updateScore(mostPlayerDamage, npc, 1000, false);
				Race winningRace = kamarBattlefieldReward.getWinningRaceByScore();
				stopInstance(winningRace);
			}
			return;
		}
		super.onDie(npc);
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		switch (npc.getNpcId()) {
		case 701898: //Kamar Tank Elyos.
		SkillEngine.getInstance().getSkill(npc, 21403, 1, player).useNoAnimationSkill();
		NpcActions.scheduleRespawn(npc);
		despawnNpc(npc);
		break;
		case 701899: //Kamar Tank Asmodians.
			SkillEngine.getInstance().getSkill(npc, 21404, 1, player).useNoAnimationSkill();
			NpcActions.scheduleRespawn(npc);
			despawnNpc(npc);
			break;
		}
	}

	private void removeEffects(Player player) {
		PlayerEffectController effectController = player.getEffectController();
		effectController.removeEffect(21403);
		effectController.removeEffect(21404);
	}

	@Override
	public void onLeaveInstance(Player player) {
		removeEffects(player);
	}

	@Override
	public void onPlayerLogOut(Player player) {
		removeEffects(player);
	}

	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}

	@Override
	protected void openFirstDoors() {
		openDoor(4);
		openDoor(8);
	}

	private void sendMovie(Player player, int movie) {
		if (!movies.contains(movie)) {
			movies.add(movie);
			PacketSendUtility.sendPacket(player, new SM_PLAY_MOVIE(0, movie));
		}

	}
}