/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.luna;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.ai2.NpcAI2;
import com.aionemu.gameserver.ai2.manager.WalkManager;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.LunaInstanceReward;
import com.aionemu.gameserver.model.templates.spawns.SpawnSpotTemplate;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.player.PlayerReviveService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;
import com.aionemu.gameserver.world.zone.ZoneInstance;
import com.aionemu.gameserver.world.zone.ZoneName;

/**
 * @author 81002
 */
@InstanceID(MapID = 301630000, InstanceMaskID = 0)
public class Luna301630000 extends GeneralInstanceHandler {

	private Future<?> instanceTimer;
	private Future<?> spawnTask;
	private long startTime;
	private Map<Integer, StaticDoor> doors;
	private LunaInstanceReward instanceReward;
	private List<SpawnSpotTemplate> spots = new ArrayList<SpawnSpotTemplate>();
	private List<Npc> spawnNpcs = new ArrayList<Npc>();
	private int step1,step2,step3,step4,step5;
	private Npc heal1, heal2;

	@Override
	public void onDie(Npc npc) {
		Creature master = npc.getMaster();
		if (master instanceof Player)
			return;
		
		int npcId = npc.getNpcId();
		int point = 0;
		switch (npcId) {
			case 245549:
			case 243647:
				step1++;
				point = 1500;
				if (step1 == 1) {
					PacketSendUtility.sendPacket(instance.getPlayersInside().get(0), new SM_SYSTEM_MESSAGE(1403637));
					spawnStep(245543, 24, 1);
				}
				break;
			case 245543:
				step2++;
				point = 1500;
				if (step2 == 6) {
					spawnStep(245544, 24, 1);
				}
				break;
			case 245544:
				step3++;
				point = 150;
				if (step3 == 6) {
					spawnStep(245572, 10, 1);
				}
				if (step3 + step4 == 10) {
					spawnStep5();
					spawnStep(245575, 1, 3);
				}
				break;
			case 245572:
				step4++;
				point = 300;
				if (step4 == 3) {
					spawnStep(245573, 10, 1);
				}
				if (step5 + step4 == 6) {
					spawnStep5();
					spawnStep(245575, 1, 3);
				}
				break;
			case 245573:
				step5++;
				point = 300;
				if (step5 == 3) {
					spawnStep(245564, 26, 1);
				}
				break;
			case 245574:
			case 246173:
				point = 1500;
				break;
			case 245575:
				int min = (int)(getTime() / 1000 / 60);
				point = min * 10000;
				break;
		}
		if (point > 0) {
			if (instanceReward.getInstanceScoreType().isStartProgress()) {
				instanceReward.addPoints(point);
				if (npcId == 245575)
					stopInstanceTask();
				sendPacket(0, point);
			}
		}
		spawnNpcs.remove(npc);
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}

	private void StartInstanceTask() {
		if (!instanceReward.isStartProgress()) {
			startTime = System.currentTimeMillis();
			instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					stopInstanceTask();
					sendPacket(0, 0);
				}
			}, 3600000);
			sendPacket(0, 0);
			startSpawnTask();
			PacketSendUtility.sendPacket(instance.getPlayersInside().get(0), new SM_SYSTEM_MESSAGE(1403636));
		}
	}

	private void startSpawnTask() {

		spawnTask = ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				spawnStep(245549, 2, 1);
				ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						spawnStep(243647, 1, 3);
					}
				}, 10000);
			}
		}, 10000);
	}
	
	private void spawnStep5() {
		spawn(246173, 234.5652f, 255.4063f, 159.6885f, (byte)60);
		spawn(246173, 225.1612f, 254.2357f, 159.6885f, (byte)60);
		spawn(246173, 224.1040f, 253.6321f, 159.6885f, (byte)60);
		spawn(246173, 223.3506f, 251.2763f, 159.6885f, (byte)60);
		spawn(246173, 226.3545f, 251.3455f, 159.6885f, (byte)60);
		spawn(246173, 235.2589f, 250.4918f, 159.6885f, (byte)60);
		spawn(246173, 232.7028f, 251.9657f, 159.6885f, (byte)60);
		spawn(246173, 224.3404f, 255.2181f, 159.6885f, (byte)60);
	}
	
	private void spawnStep(int npcid, int size, int walkerid) {
		int index = 0;
		for (int i = 0; i < size; i++) {
			Npc npc;
			if (index == 0) {
				npc = (Npc) spawn(npcid, spots.get(0));
			}
			else {
				npc = (Npc) spawn(npcid, spots.get(1));
			}
			spawnNpcs.add(npc);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_30163000" + (walkerid + index));
			WalkManager.startWalking((NpcAI2) npc.getAi2());
			if (index == 1) {
				try {
					Thread.sleep(500);
				}
				catch (Exception e) {
				}
				index = 0;
			}
			else {
				index = 1;
			}
		}
	}

	private void stopInstanceTask() {
		if (instanceTimer != null)
			instanceTimer.cancel(true);
		checkRank(instanceReward.getPoints());
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
	}

	private void checkRank(int totalPoints) {
		int timeRemain = getTime();
		int rank = 0;
		if (timeRemain > 0 && totalPoints >= 540000) {
			rank = 1;
		}
		else if (timeRemain > 0 && totalPoints >= 0) {
			rank = 2;
		}
		instanceReward.setRank(rank);
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		instanceReward = new LunaInstanceReward(mapId, instanceId);
		doors = instance.getDoors();
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
		spots.add(new SpawnSpotTemplate(225.6075f, 288.6454f, 160.3114f, (byte) 60, 0, "", null));
		spots.add(new SpawnSpotTemplate(231.6075f, 288.6454f, 160.3114f, (byte) 60, 0, "", null));
		heal1 = (Npc) spawn(834491, 236.9987f, 215.5958f, 160.2815f, (byte) 90);
		heal2 = (Npc) spawn(834491, 236.6347f, 202.5351f, 160.2815f, (byte) 90);
	}

	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 180000 && !instanceReward.isStartProgress()) {
			return (int) (180000 - result);
		}
		else if (result < 3600000) {
			return (int) (3600000 - result);
		}
		return 0;
	}

	private void sendPacket(final int nameId, final int point) {
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player player) {
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, null));
			}
		});
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(28);
				}
			}, 180000);
		}
		sendPacket(0, 0);
		SkillEngine.getInstance().applyEffectDirectly(21345, player, player, 0);
	}
	
	@Override
	public void onCustomEventHandler(int eventId, Object... objects) {
		if (eventId == 833863)
			heal1.getController().delete();
		else if (eventId == 833864)
			heal2.getController().delete();
	}
	
	@Override
	public void doReward(Player player) {
		if (instanceReward.isRewarded()) {
			int itemId = instanceReward.getRank() == 1 ? 188055598 : 188055597;
			ItemService.addItem(player, itemId, 1);
		}
	}
	
	@Override
	public void onLeaveInstance(Player player) {
		player.getEffectController().removeEffect(21345);
	}
	
	@Override
	public void onInstanceDestroy() {
		instanceTimer.cancel(true);
		spawnTask.cancel(true);
	}
	
	@Override
	public void onEnterZone(Player player, ZoneInstance zone) {
		if (zone.getAreaTemplate().getZoneName() == ZoneName.get("TZ_DAMAGEZONE")) {
			player.getController().die();
		}
	}
	
  @Override
  public boolean onDie(final Player player, Creature lastAttacker) {
      PacketSendUtility.broadcastPacket(player, new SM_EMOTION(player, EmotionType.DIE, 0, player.equals(lastAttacker) ? 0 : lastAttacker.getObjectId()), true);
      PacketSendUtility.sendPacket(player, new SM_DIE(player.haveSelfRezEffect(), player.haveSelfRezItem(), 0, 8));
      return true;
  }
  
  @Override
	public boolean onReviveEvent(Player player) {
  	PlayerReviveService.revive(player, 100, 100, false, 0);
		player.getGameStats().updateStatsAndSpeedVisually();
  	TeleportService2.teleportTo(player, player.getWorldId(), player.getInstanceId(), 299.0011F, 171.8445F, 164.6003F, (byte) 20);
  	return true;
  }

	@Override
	public void onExitInstance(Player player) {
		long count = player.getInventory().getItemCountByItemId(182007405);
		if (count > 0)
			player.getInventory().decreaseByItemId(182007405, count);
		TeleportService2.teleportTo(player, player.getEnterWorldId(), player.getEnterX(), player.getEnterY(), player.getEnterZ(), player.getHeading(), TeleportAnimation.BEAM_ANIMATION);
	}
}
