/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.voidcube;

import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.DescriptionId;
import com.aionemu.gameserver.model.flyring.FlyRing;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.VoidCubeReward;
import com.aionemu.gameserver.model.templates.flyring.FlyRingTemplate;
import com.aionemu.gameserver.model.utils3d.Point3D;
import com.aionemu.gameserver.network.aion.serverpackets.SM_ATTACK_STATUS.LOG;
import com.aionemu.gameserver.network.aion.serverpackets.SM_ATTACK_STATUS.TYPE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.abyss.AbyssPointsService;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.player.PlayerReviveService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author zxl001
 */
@InstanceID(MapID = 300580000, InstanceMaskID = 0)
public class Void_Cube_Solo extends GeneralInstanceHandler {

	private long startTime;
	private Future<?> instanceTimer;
	@SuppressWarnings("unused")
	private boolean isInstanceDestroyed;
	private Map<Integer, StaticDoor> doors;
	private VoidCubeReward instanceReward;

	@Override
	public void onDie(Npc npc) {
		int points = 0;
		switch (npc.getNpcId()) {
			case 230084:
			case 230094:
				points = 25;
				break;
			case 230087:
				points = 50;
				break;
			case 230095:
			case 230097:
				points = 75;
				break;
			case 230090:
			case 230091:
			case 230098:
			case 230099:
				points = 150;
				break;
			case 230085:
			case 230411:
			case 230412:
				points = 200;
				break;
			case 230088:
			case 230089:
				points = 225;
				break;
			case 230086:
				points = 450;
				break;
			case 230355:
				points = 900;
				break;
			case 230093:
				points = 1000;
				break;
		}
		if (npc.getNpcId() == 230387)
			stopInstance();
		else if (instanceReward.getInstanceScoreType().isStartProgress()) {
			instanceReward.addPoints(points);
			if (instanceReward.getPoints() >= 10000)
				stopInstance();
			else
				sendPacket(npc.getObjectTemplate().getNameId(), points);
		}
	}

	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 60000 && !instanceReward.isStartProgress())
			return (int) (60000 - result);
		else if (result < 1500000 && instanceReward.isStartProgress())
			return (int) (1500000 - result);
		return 0;
	}

	private void sendPacket(final int nameId, final int point) {
		instance.doOnAllPlayers(new Visitor<Player>() {
			@Override
			public void visit(Player player) {

				if (nameId != 0) {
					PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1400237, new DescriptionId(nameId * 2 + 1), point));
				}
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, null));
			}
		});
	}

	private int checkRank(int totalPoints) {
		int rank = 7;
		long Remainingtime = System.currentTimeMillis() - startTime;
		if (totalPoints > 10000 && Remainingtime <= 660000) { // Rank S.
			rank = 1;
		}
		else if (totalPoints > 6800 && Remainingtime <= 900000) { // Rank A.
			rank = 2;
		}
		else if (totalPoints > 5700 && Remainingtime <= 900000) { // Rank B.
			rank = 3;
		}
		else if (totalPoints > 3900 && Remainingtime <= 1200000) { // Rank C.
			rank = 4;
		}
		else if (totalPoints > 1800 && Remainingtime <= 1200000) { // Rank D.
			rank = 5;
		}
		else {
			rank = 8;
		}
		return rank;
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(26);
				}
			}, 60000);
		}
		sendPacket(0, 0);
	}

	protected void stopInstance() {
		stopInstanceTask();
		int rank = checkRank(instanceReward.getPoints());
		if (rank <= 5)
			spawn(730729, 254.687775f, 276.070099f, 57.071781f, (byte) 0);
		instanceReward.setRank(rank);
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
		if (!instanceReward.isRewarded()) {
			instanceReward.setRewarded();
			instance.doOnAllPlayers(new Visitor<Player>() {

				@Override
				public void visit(Player object) {
					doReward(object);
				}
			});
			sendPacket(0, 0);
		}
	}

	private void stopInstanceTask() {
		if (instanceTimer != null) {
			instanceTimer.cancel(true);
		}
	}

	@Override
	public void doReward(Player player) {
		int rank = checkRank(instanceReward.getPoints());
		if (rank <= 5) {
			float rewardSillus = (instanceReward.getPoints() >> 8) / (rank + 7);
			float rewardAp = (instanceReward.getPoints() * 0.06f) - rank * 200;
			instanceReward.setScoreAP((int) rewardAp);
			AbyssPointsService.addAGp(player, (int) rewardAp, 0); // 欧比斯
			if (rewardSillus > 1) {
				instanceReward.setSillus((int) rewardSillus);
				ItemService.addItem(player, 186000240, (int) rewardSillus); // 要塞纹章
			}
			if (rank == 1) {
				instanceReward.setCeramium(1);
				ItemService.addItem(player, 186000242, 1); // 黑金铸币.
				ItemService.addItem(player, 188052543, 1); // 荣誉奖励品
			}
			else if (rank == 2) {
				instanceReward.setFavorable(3);
				ItemService.addItem(player, 186000243, 3); // 破碎的黑金
				ItemService.addItem(player, 188052547, 1); // 勇敢奖励品
			}
			else if (rank == 3) {
				instanceReward.setFavorable(1);
				ItemService.addItem(player, 186000243, 1); // 破碎的黑金
			}
		}
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		instanceReward = new VoidCubeReward(mapId, instanceId);
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
		doors = instance.getDoors();
		spawnRings();
	}

	@Override
	public void onInstanceDestroy() {
		if (instanceTimer != null)
			instanceTimer.cancel(false);
		isInstanceDestroyed = true;
		instanceReward.clear();
		doors.clear();
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}

	private void StartInstanceTask() {

		if (!instanceReward.isStartProgress()) {
			startTime = System.currentTimeMillis();
			instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
			instanceReward.getInstanceScoreType().isStartProgress();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {
				
				@Override
				public void run() {
					stopInstance();
				}
			}, 1500000);
			sendPacket(0, 0);
		}
	}

	private void spawnRings() {
		FlyRing f1 = new FlyRing(new FlyRingTemplate("VOIDCUBE_FLYRING", mapId, 
			new Point3D(213.65, 221.41, 286.13), 
			new Point3D(213.65, 225.91, 294.34), 
			new Point3D(213.65, 229.86, 286.13), 8), instanceId);
		f1.spawn();
		FlyRing f2 = new FlyRing(new FlyRingTemplate("VOIDCUBE_FLYRING", mapId, 
			new Point3D(294.93, 227.41, 215.11), 
			new Point3D(289.18, 227.41, 224.90), 
			new Point3D(284.07, 227.41, 215.11), 8), instanceId);
		f2.spawn();
		FlyRing f3 = new FlyRing(new FlyRingTemplate("VOIDCUBE_FLYRING", mapId, 
			new Point3D(290.28, 303.73, 252.17), 
			new Point3D(291.29, 298.08, 261.41), 
			new Point3D(291.32, 293.78, 252.17), 8), instanceId);
		f3.spawn();
		FlyRing f4 = new FlyRing(new FlyRingTemplate("VOIDCUBE_FLYRING", mapId, 
			new Point3D(252.82, 299.17, 180.47), 
			new Point3D(252.61, 304.41, 190.38), 
			new Point3D(253.17, 309.01, 180.47), 8), instanceId);
		f4.spawn();
		FlyRing f5 = new FlyRing(new FlyRingTemplate("VOIDCUBE_FLYRING", mapId, 
			new Point3D(284.78, 231.46, 322.89), 
			new Point3D(284.78, 225.74, 332.33), 
			new Point3D(284.78, 221.06, 322.89), 8), instanceId);
		f5.spawn();
	}

	@Override
	public boolean onPassFlyingRing(Player player, String flyingRing) {
		if (flyingRing.equals("VOIDCUBE_FLYRING")) {
			player.getLifeStats().increaseFp(TYPE.FP, 60, 21402, LOG.HEAL);
		}
		return true;
	}

	@Override
	public void onStopTraining(Player player) {
		onExitInstance(player);
	}

	@Override
	public void onExitInstance(Player player) {
		TeleportService2.moveToInstanceExit(player, mapId, player.getRace());
	}

	@Override
	public boolean onReviveEvent(Player player) {
		PlayerReviveService.revive(player, 100, 100, false, 0);
		player.getLifeStats().increaseFp(TYPE.FP, player.getLifeStats().getMaxFp());
		player.getGameStats().updateStatsAndSpeedVisually();
		PacketSendUtility.sendPacket(player, SM_SYSTEM_MESSAGE.STR_REBIRTH_MASSAGE_ME);
		TeleportService2.teleportTo(player, mapId, instanceId, 183.77718f, 261.03903f, 310.0941f, (byte) 0);
		return true;
	}
}
