/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author 81002
 */
public class _10101WarPremonition extends QuestHandler {

	private final static int questId = 10101;

	public _10101WarPremonition() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(802462).addOnTalkEvent(questId);
		qe.registerQuestNpc(731530).addOnTalkEvent(questId);
		qe.registerQuestNpc(234680).addOnKillEvent(questId);
		qe.registerQuestNpc(234193).addOnKillEvent(questId);
		qe.registerQuestNpc(804556).addOnTalkEvent(questId);
		qe.registerQuestNpc(731532).addOnTalkEvent(questId);
		qe.registerQuestNpc(802357).addOnTalkEvent(questId);
		qe.registerQuestNpc(802431).addOnTalkEvent(questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 802462:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							giveQuestItem(env, 182215521, 1);
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 731530:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							if (removeQuestItem(env, 182215521, 1)) {
								changeQuestStep(env, 1, 2, false);
								WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(301270000, 0);
								InstanceService.registerPlayerWithInstance(newInstance, player);
								return TeleportService2.teleportTo(player, 301270000, newInstance.getInstanceId(), 361f, 260f, 311.365f, (byte) 60, TeleportAnimation.BEAM_ANIMATION);
							}
					}
					break;
				case 804556:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6, 182215520, 1, 0, 0);
					}
					break;
				case 731532:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							TeleportService2.teleportTo(player, 600090000, 1359f, 939f, 155f, (byte)60, TeleportAnimation.BEAM_ANIMATION);
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 802357:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 7)
								return sendQuestDialog(env, 3398);
							else if (var == 8)
								return sendQuestDialog(env, 3739);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 7, 8, false, 10000, 10001);
						case SET_REWARD:
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return TeleportService2.teleportTo(player, 600090000, 1303f, 1310, 200, (byte)100, TeleportAnimation.BEAM_ANIMATION);
					}
			}
		}
		else {
			if (targetId == 802431 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		int targetId = env.getTargetId();
		if (var == 4 && targetId == 234193) {
			return defaultOnKillEvent(env, 234193, var, false);
		}
		else if (var > 1 && var < 4) {
		  return defaultOnKillEvent(env, 234680, var, false);
		}
		return false;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		if (qs.getStatus() == QuestStatus.START) {
			int var = qs.getQuestVarById(0);
			if (player.getWorldId() != 301270000) {
				if (var > 1 && var < 7) {
					qs.setQuestVar(0);
					updateQuestStatus(env);
					return true;
				}
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
