/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 */
public class _10501RuinedRuins extends QuestHandler {

	private final static int questId = 10501;

	public _10501RuinedRuins() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804700).addOnTalkEvent(questId);
		qe.registerQuestNpc(731536).addOnTalkEvent(questId);
		qe.registerQuestNpc(731535).addOnTalkEvent(questId);
		qe.registerQuestItem(182215598, questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}

	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		int var = qs.getQuestVarById(0);

		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch (targetId) {
				case 804700:
					switch (env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
							  return sendQuestDialog(env, 1011);
							else if (var == 6)
								return sendQuestDialog(env, 3057);
						case STEP_TO_1:
							giveQuestItem(env, 182215598, 1);
							return defaultCloseDialog(env, 0, 1);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 6, 7, false, 10000, 10001);
						case FINISH_DIALOG:
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return sendQuestDialog(env, 10002);
					}
					break;
				case 731536:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 731535:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_3:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 804700)
				return sendQuestEndDialog(env);
		}
		return false;
	}

	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return HandlerResult.UNKNOWN;
		int var = qs.getQuestVarById(0);
		if (item.getItemId() == 182215598) {
			if (var == 1)
				return HandlerResult.fromBoolean(useQuestItem(env, item, 1, 2, false));
			else if (var == 3)
				return HandlerResult.fromBoolean(useQuestItem(env, item, 3, 4, false));
			else if (var == 5)
				return HandlerResult.fromBoolean(useQuestItem(env, item, 5, 6, false));
		}
		return HandlerResult.UNKNOWN;
	}

	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
