/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _10505TrackingBrittLa extends QuestHandler {

	private final static int questId = 10505;

	public _10505TrackingBrittLa() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804707).addOnTalkEvent(questId);
		qe.registerQuestNpc(804708).addOnTalkEvent(questId);
		qe.registerQuestNpc(702672).addOnTalkEvent(questId);
		qe.registerQuestItem(182215612, questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 804707:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 804708:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 2) 
								return sendQuestDialog(env, 1693);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 2, 3, false, 10000, 10001);
						case STEP_TO_4:
							giveQuestItem(env, 182215612, 1);
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 702672:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 2, 2, false, true);
					}
					break;
			}
		}
		else {
			if (targetId == 804707 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		if (item.getItemId() == 182215612) {
			if (HandlerResult.fromBoolean(useQuestItem(env, item, 4, 5, false)) == HandlerResult.SUCCESS) {
				Player player = env.getPlayer();
				QuestState qs = player.getQuestStateList().getQuestState(questId);
				qs.setStatus(QuestStatus.REWARD);
				updateQuestStatus(env);
				return HandlerResult.SUCCESS;
			}
		}
		return HandlerResult.UNKNOWN;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
