/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 */
public class _10530OracleCall extends QuestHandler {

	private final static int questId = 10530;

	public _10530OracleCall() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(203752).addOnTalkEvent(questId);
		qe.registerQuestNpc(203725).addOnTalkEvent(questId);
		qe.registerQuestNpc(703386).addOnTalkEvent(questId);
		qe.registerQuestNpc(798440).addOnTalkEvent(questId);
		qe.registerQuestNpc(203852).addOnTalkEvent(questId);
		qe.registerQuestNpc(806555).addOnTalkEvent(questId);
		qe.registerQuestNpc(703394).addOnTalkEvent(questId);
		qe.registerQuestNpc(703390).addOnTalkEvent(questId);
		qe.registerQuestNpc(703387).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}

	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch (targetId) {
				case 203752:
					switch (env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
								return sendQuestDialog(env, 1011);
							else if (var == 7)
								return sendQuestDialog(env, 3398);
							else if (var == 8)
								return sendQuestDialog(env, 3739);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 7, 8, false, 10000, 10001);
						case SELECT_REWARD:
							qs.setQuestVarById(0, 9);
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
					break;
				case 203725:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 703386:
					switch (env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 2, 2, false, false);
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 798440:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 203852:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 806555:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 703394:
					switch (env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 6, 6, false, false);
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 703390:
					switch (env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 7, 7, false, true);
					}
					break;
				case 703387:
					switch (env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 7, 7, false, true);
					}
					break;
			}
		}
		else {
			if (targetId == 203752 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}

	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
