/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.convent_of_marchutan;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.utils.PacketSendUtility;


/**
 * @author 81002
 *
 */
public class _20031SupportCommand extends QuestHandler {

	private final static int questId = 20031;
	private final static int[] mob_ids = new int[] { 216091, 216092, 216093, 216095 };
	public _20031SupportCommand() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(204052).addOnTalkEvent(questId);
		qe.registerQuestNpc(798800).addOnTalkEvent(questId);
		qe.registerQuestNpc(798409).addOnTalkEvent(questId);
		qe.registerQuestNpc(799225).addOnTalkEvent(questId);
		qe.registerQuestNpc(799364).addOnTalkEvent(questId);
		qe.registerQuestNpc(799365).addOnTalkEvent(questId);
		qe.registerQuestNpc(799226).addOnTalkEvent(questId);
		for (int id : mob_ids)
			qe.registerQuestNpc(id).addOnKillEvent(questId);
		qe.registerQuestItem(182215590, questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 204052:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 798800:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 798409:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 799225:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 799364:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 799365:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 799226:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 7)
								return sendQuestDialog(env, 3398);
							else if (var == 10)
								return sendQuestDialog(env, 6500);
						case STEP_TO_8:
							return defaultCloseDialog(env, 7, 8, 182215590, 1, 0, 0);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 10, 11, true, 10000, 10001);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 799225) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;
		int var = qs.getQuestVarById(0);
		if (var == 3) {
			if (player.getWorldId() == 220070000) {
				changeQuestStep(env, 3, 4, false);
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;
		int var = qs.getQuestVarById(1);
		if (var < 9)
			return defaultOnKillEvent(env, mob_ids, 0, 10, 1);
		else if (var == 9) {
			qs.setQuestVarById(1, 0);
			qs.setQuestVarById(0, 9);
			updateQuestStatus(env);
			return true;
		}
		return false;
	}
	
	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		return HandlerResult.fromBoolean(useQuestItem(env, item, 9, 10, false));
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
