/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.danaria;

import com.aionemu.gameserver.dataholders.DataManager;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.SystemMessageId;
import com.aionemu.gameserver.network.aion.serverpackets.SM_PLAY_MOVIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author Romanz
 * @Wasacacax
 */
public class _10090IdgelIfYouAskMe extends QuestHandler {

	private final static int questId = 10090;
	
	private final static int[] mobs = {701545};
	

	public _10090IdgelIfYouAskMe() {
		super(questId);
	}

	@Override
	public void register() {
		int[] npcIds = { 800566, 800816, 730734, 800817, 730735, 800818, 800820 };
		qe.registerOnEnterWorld(questId);
		qe.registerOnMovieEndQuest(851, questId);
		qe.registerQuestNpc(206288).addOnAtDistanceEvent(questId);
		qe.registerOnLevelUp(questId);
		for (int npcId : npcIds) {
			qe.registerQuestNpc(npcId).addOnTalkEvent(questId);
		}
		for (int mob : mobs) {
			qe.registerQuestNpc(mob).addOnKillEvent(questId);
		}
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 10085);
	}

	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		int targetId = env.getTargetId();
		QuestDialog dialog = env.getDialog();
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			if (targetId == 800566) {
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 0) {
							return sendQuestDialog(env, 1011);
						}
					}
					case STEP_TO_1: {
						return defaultCloseDialog(env, 0, 1);
					}
				}
			}
			else if (targetId == 800816) { 
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 1) {
							return sendQuestDialog(env, 1352);
						}
					}
					case STEP_TO_2: {
						return defaultCloseDialog(env, 1, 2); 
					}
				}
			}
			else if (targetId == 730734) { 
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 2) {
							return sendQuestDialog(env, 1693);
						}
					}
					case STEP_TO_3: {
						WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(301000000, 0);
						InstanceService.registerPlayerWithInstance(newInstance, player);
						TeleportService2.teleportTo(player, 301000000, newInstance.getInstanceId(), 214.67f, 508.323f, 153.23f, (byte) 30, TeleportAnimation.BEAM_ANIMATION);
						return defaultCloseDialog(env, 2, 3); 
					}
				}
			}
			else if (targetId == 800817) { 
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 3) {
							return sendQuestDialog(env, 2034);
						}
					}
					case STEP_TO_4: {
						return defaultCloseDialog(env, 3, 4); 
					}
				}
			}
			else if (targetId == 730735) { 
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 6) {
							return sendQuestDialog(env, 3057);
						}
					}
					case STEP_TO_7: {
					QuestService.addNewSpawn(301000000, player.getInstanceId(), 800818,  551.692383f, 430.005890f,  94.892334f, (byte) 45);
						return defaultCloseDialog(env, 6, 8); 
					}
				}
			}
			else if (targetId == 800818) { 
				switch (dialog) {
					case START_DIALOG: {
						if (qs.getQuestVarById(0) == 8) {
							return sendQuestDialog(env, 3398);
						}
					}
					case SET_REWARD: {
						TeleportService2.teleportTo(player, 600060000, 1529.14f, 2922.8213f, 221.8727f, (byte) 30, TeleportAnimation.BEAM_ANIMATION);
						return defaultCloseDialog(env, 8, 9, true, false); 
					}
				}
			}
		}
		else if (qs != null && qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 800820) {
				if (dialog == QuestDialog.USE_OBJECT) {
					return sendQuestDialog(env, 5);
				}
				else {
					return sendQuestEndDialog(env);
				}
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		return defaultOnKillEvent(env, mobs, 1, 5, 0);
	}
	
	@Override
	public boolean onAtDistanceEvent(QuestEnv env) {
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			if (qs.getQuestVarById(0) == 5) {
				changeQuestStep(env, 5, 6, false);
	  		return true;
			}
  	}
		return false;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
      int var = qs.getQuestVarById(0);
			if (player.getWorldId() == 301000000) {
				if (var == 3) {
					QuestService.addNewSpawn(301000000, player.getInstanceId(), 800817,  218.569061f, 510.007294f,  153.22841f, (byte) 68);
					PacketSendUtility.sendPacket(player, new SM_PLAY_MOVIE(0, 851));
					return true;
				}
			}
			else {
        if (var >= 3) {
        	qs.setQuestVarById(0, 0);
  				updateQuestStatus(env);
          return true;
        }
      }
		}
		return false;
	}
	
	@Override
	public boolean onDieEvent(QuestEnv env){
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs != null && qs.getStatus() == QuestStatus.START){
			int var = qs.getQuestVarById(0);
			if (var >= 1) {
				qs.setQuestVar(0);
				updateQuestStatus(env);
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(SystemMessageId.QUEST_FAILED_$1,
				DataManager.QUEST_DATA.getQuestById(questId).getName()));
				return true;
			}
		}
		return false;
	}
}
