/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.eltnen;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 */
public class _14021CursedManduri extends QuestHandler {

	private final static int questId = 14021;
	private final static int[] mob_ids = new int[] { 210758, 210759, 210763, 210764, 210770, 210771 };
	
	public _14021CursedManduri() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(203902).addOnTalkEvent(questId);
		qe.registerQuestNpc(700179).addOnTalkEvent(questId);
		qe.registerQuestNpc(204043).addOnTalkEvent(questId);
		qe.registerQuestNpc(204030).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
		for (int id : mob_ids)
			qe.registerQuestNpc(id).addOnKillEvent(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 203902:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case SELECT_ACTION_1013:
							changeQuestStep(env, 0, 1, false);
							return sendQuestDialog(env, 1013);
						case STEP_TO_1:
							return closeDialogWindow(env);
					}
					break;
				case 700179:
					switch(env.getDialog()) {
						case USE_OBJECT:
							if (var == 7) {
								useQuestObject(env, 7, 8, false, false);
								return sendQuestDialog(env, 1693);
							}
							break;
						case STEP_TO_3:
							return closeDialogWindow(env);
					}
					break;
				case 204043:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							return defaultCloseDialog(env, 8, 9);
					}
					break;
				case 204030:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
			}
		}
		else {
			if (targetId == 203902 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 2716);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		return defaultOnKillEvent(env, mob_ids, 1, 7);
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14020, true);
	}
}
