/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.heiron;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;

/**
 * @author 81002
 *
 */
public class _14052Eternalrest extends QuestHandler {

	private final static int questId = 14052;
	
	public _14052Eternalrest() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(204629).addOnTalkEvent(questId);
		qe.registerQuestNpc(204628).addOnTalkEvent(questId);
		qe.registerQuestNpc(204627).addOnTalkEvent(questId);
		qe.registerQuestNpc(204626).addOnTalkEvent(questId);
		qe.registerQuestNpc(204625).addOnTalkEvent(questId);
		qe.registerQuestNpc(204622).addOnTalkEvent(questId);
		qe.registerQuestNpc(700270).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 204629:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							changeQuestStep(env, 0, 1, false);
							return closeDialogWindow(env);
					}
					break;
				case 204625:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 4)
								return sendQuestDialog(env, 2375);
						case STEP_TO_2:
							changeQuestStep(env, 1, 2, false);
							return closeDialogWindow(env);
						case SET_REWARD:
							changeQuestStep(env, 4, 4, true);
							return closeDialogWindow(env);
					}
					break;
				case 204628:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1694);
						case STEP_TO_3:
							giveQuestItem(env, 182215340, 1);
							if (QuestService.collectItemCheck(env, false))
								changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
					}
					break;
				case 204627:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1779);
						case STEP_TO_3:
							giveQuestItem(env, 182215341, 1);
							if (QuestService.collectItemCheck(env, false))
								changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
					}
					break;
				case 204626:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1864);
						case STEP_TO_3:
							giveQuestItem(env, 182215342, 1);
							if (QuestService.collectItemCheck(env, false))
								changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
					}
					break;
				case 204622:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1949);
						case STEP_TO_3:
							giveQuestItem(env, 182215343, 1);
							if (QuestService.collectItemCheck(env, false))
								changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
					}
					break;
				case 700270:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 3, 4, false, false);
					}
			}
		}
		else {
			if (targetId == 204629 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.START_DIALOG)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14050, true);
	}
}
