/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.inggison;

import java.util.Arrays;
import java.util.List;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.QuestEngine;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 *
 */
public class _10031Supportcommand extends QuestHandler {

	private final static int questId = 10031;
	private final static List<Integer> mob_ids = Arrays.asList(215504, 216783, 215505, 216463, 216648, 216647, 215508, 215509);
	public _10031Supportcommand() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(203700).addOnTalkEvent(questId);
		qe.registerQuestNpc(798600).addOnTalkEvent(questId);
		qe.registerQuestNpc(798408).addOnTalkEvent(questId);
		qe.registerQuestNpc(798926).addOnTalkEvent(questId);
		qe.registerQuestNpc(799052).addOnTalkEvent(questId);
		qe.registerQuestNpc(798927).addOnTalkEvent(questId);
		qe.registerQuestNpc(730224).addOnTalkEvent(questId);
		qe.registerQuestNpc(702662).addOnTalkEvent(questId);
		for(int id : mob_ids)
			qe.registerQuestNpc(id).addOnKillEvent(questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 203700:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 798600:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 798408:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 798926:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 799052:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 798927:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 730224:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 7, 7, false, false);
							return sendQuestDialog(env, 3398);
						case STEP_TO_8:
							return defaultCloseDialog(env, 7, 8);
					}
					break;
				case 702662:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 8, 9, false, false);
					}
					break;
			}
		}
		else if (targetId == 798927 && qs.getStatus() == QuestStatus.REWARD) {
			if (env.getDialog() == QuestDialog.USE_OBJECT)
				return sendQuestDialog(env, 10002);
			if (env.getDialogId() == 23) {
				int[] ids = { 10032, 10033, 10034, 10035 };
				for (int id : ids) {
					QuestEngine.getInstance().onEnterZoneMissionEnd(new QuestEnv(env.getVisibleObject(), env.getPlayer(), id, env.getDialogId()));
				}
			}
			return sendQuestEndDialog(env);
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		if (var != 9)
			return false;
		int var1 = qs.getQuestVarById(1);
		int var2 = qs.getQuestVarById(2);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		switch(targetId) {
			case 215504:
			case 216783:
			case 215505:
			case 216463:
			case 216648:
			case 216647:
				if (var2 == 2 && var1 + 1 == 10) {
					qs.setQuestVarById(0, 10);
					qs.setStatus(QuestStatus.REWARD);
					updateQuestStatus(env);
					return true;
				}
				return defaultOnKillEvent(env, targetId, 0, 10, 1);
			case 215508:
			case 215509:
				if (var1 == 10 && var2 + 1 == 2) {
					qs.setQuestVarById(0, 10);
					qs.setStatus(QuestStatus.REWARD);
					updateQuestStatus(env);
					return true;
				}
				return defaultOnKillEvent(env, targetId, 0, 2, 2);
		}
		return false;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		Player player = env.getPlayer();
		if (player.getWorldId() == 210050000) {
			QuestState qs = player.getQuestStateList().getQuestState(questId);
			if (qs != null) {
				int var = qs.getQuestVarById(0);
				if (var == 3)
					changeQuestStep(env, 3, 4, false);
			}
		}
		return false;
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
