/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone147;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _25400FonteKanescall extends QuestHandler {

	private static final int questId = 25400;
	/**
	 * @param questId
	 */
	public _25400FonteKanescall() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(805356).addOnTalkEvent(questId);
		qe.registerQuestNpc(805357).addOnTalkEvent(questId);
		qe.registerQuestNpc(805358).addOnTalkEvent(questId);
		qe.registerQuestNpc(805359).addOnTalkEvent(questId);
		qe.registerQuestNpc(805360).addOnTalkEvent(questId);
		qe.registerQuestNpc(702833).addOnTalkEvent(questId);
		qe.registerQuestNpc(702834).addOnTalkEvent(questId);
		qe.registerQuestNpc(702835).addOnTalkEvent(questId);
		qe.registerQuestNpc(206472).addOnAtDistanceEvent(questId);
		qe.registerQuestNpc(883643).addOnKillEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 805356:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 805357:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 8)
								return sendQuestDialog(env, 3739);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case SET_REWARD:
							return defaultCloseDialog(env, 8, 9, true, false);
					}
					break;
				case 805358:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 702833:
				case 702834:
				case 702835:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 3, 3, false, true);
					}
					break;
				case 805359:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 3)
								return sendQuestDialog(env, 2034);
							else if (var == 4)
								return sendQuestDialog(env, 2375);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 3, 4, false, 10000, 10001);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 805360:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3398);
						case STEP_TO_8:
							return defaultCloseDialog(env, 7, 8);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 805356) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;

		int var = qs.getQuestVarById(0);
		if (var == 6) {
			int var1 = qs.getQuestVarById(1);
			if (var1 == 0)
				return defaultOnKillEvent(env, 883643, 0, 2, 1);
			else if (var1 == 1) {
				qs.setQuestVarById(1, 0);
				return defaultOnKillEvent(env, 883643, 6, false);
			}
		}
		return false;
	}
	
	@Override
	public boolean onAtDistanceEvent(QuestEnv env) {
		return defaultFollowEndEvent(env, 5, 6, false);
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
